pub enum StreamId {
SvStream(SvStreamId),
AppStream(AppStreamId),
SysStream(SysStreamId),
GooseStream(GooseStreamId),
}Variants
Implementations
Sourceimpl StreamId
impl StreamId
Sourcepub fn merge(
field: &mut Option<StreamId>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<StreamId>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.