Connection

Struct Connection 

pub struct Connection<A: App> { /* private fields */ }

Implementations

Source

impl<A: App> Connection<A>

pub fn connect_to_stream( &mut self, input_stream: &InputStream, ) -> Result<StreamInfo, Error>

Subscribe to a stream in the framework. Returns StreamInfo on success. Any packets received on the stream will route through handle_packet. Subscribing to the same stream multiple times is idempotent - the second and subsequent calls for the same stream will return early without creating duplicate subscription threads.

pub fn register_out_stream( &mut self, stream_name: &str, ) -> Result<OutStream, Error>

Register an output stream.

pub fn get_event_sender(&mut self) -> Box<dyn Fn(A::AppEvent) + Send>