Sinusoidal

Struct Sinusoidal 

pub struct Sinusoidal<A: App> { /* private fields */ }
Handles communication with the framework and calls the App callbacks.

Implementations

Source

impl<A: App> Sinusoidal<A>

pub fn new() -> Result<Sinusoidal<A>, Error>

Create a Sinusoidal object for a given app and connect to the framework.

pub fn run(self) -> Result<(), Error>

Connect to the Sinusoidal framework and connect to the given streams. For every Datagram received on a stream App::handle_packet is called.