pub struct Sinusoidal<A: App> { /* private fields */ }Expand description
Handles communication with the framework and calls the App callbacks.
Implementations
Sourceimpl<A: App> Sinusoidal<A>
impl<A: App> Sinusoidal<A>
Sourcepub fn new() -> Result<Sinusoidal<A>, Error>
pub fn new() -> Result<Sinusoidal<A>, Error>
Create a Sinusoidal object for a given app and connect to the framework.